@@ -48,8 +48,8 @@ import osmnx as osm
 import folium
 from xarray.core import variable
 
-from lfmaptools.utilities import (_nice_round, 
-                                  _represents_int, 
+from lfmaptools.utilities import (_nice_round,
+                                  _represents_int,
                                   latlon_to_utm_epsg,
                                   _path_of_file_in_zip,
                                   csv_active_cols,
@@ -118,14 +118,14 @@ class LFSource(object):
 
     def volume(self):
         return np.trapz(self.flux, self.time)
-    
+
     def peak_flux(self):
         return np.amax(self.flux)
-    
+
     def peak_time(self):
         i = np.argmax(self.flux)
         return self.time[i]
-    
+
     def duration(self):
         return self.time[-1]-self.time[0]
 
@@ -149,7 +149,7 @@ class LaharFlowData(object):
                 return
             else:
                 self.dir = LaharFlowDir
-            
+
         if zipped:
             infoFilePath = _path_of_file_in_zip('RunInfo.txt',self._zipref)[0]
             infoFile = self._zipref.extract(infoFilePath) #,path=self.dir)
@@ -253,13 +253,13 @@ class LaharFlowData(object):
                         self.sources.append(LFSource(x=s_x, y=s_y, lat=s_lat, lon=s_lon, radius=s_radius,
                                                      time=s_time, flux=s_flux, conc=s_conc))
 
-                    
+
             self.files=[]
             self.txt_files=[]
             self.tar_files=[]
             self.nc_files=[]
             self.gz_files=[]
-            
+
             self.get_files()
             self.get_txt_files()
             self.get_nc_files()
@@ -278,7 +278,7 @@ class LaharFlowData(object):
                 self._get_parameters_from_inputfile()
             else:
                 self._get_parameters_from_runinfo()
-            
+
             if ('Maximums.nc' in self.nc_files):
                 self._get_nc_max()
             else:
@@ -286,7 +286,7 @@ class LaharFlowData(object):
                 self._get_max_speed()
                 self._get_max_conc()
                 self._get_max_bed_evolution()
-    
+
     def _get_parameters_from_inputfile(self):
         if self.zipped:
             inputFilePath = _path_of_file_in_zip(self.inputFile,self._zipref)[0]
@@ -443,40 +443,40 @@ class LaharFlowData(object):
                                                      time=s_time, flux=s_flux, conc=s_conc))
                 except:
                     pass
-                    
+
         self.parameters = parameters
-    
+
     def _grid_to_physical(self, grid_i, grid_j, tile_i, tile_j, x, y):
-      
+
       x = -0.5 * self.xSize + self.dX * ((grid_i - 1.0) * self.nXpertile + (tile_i - 0.5))
       y = -0.5 * self.ySize + self.dY * ((grid_j - 1.0) * self.nYpertile + (tile_j - 0.5))
 
       return x, y
-    
+
     def _tile_row(self, tile):
 
       row = (tile - 1) // self.nXtiles + 1
 
       return int(row)
-    
+
     def _tile_col(self, tile):
-      
+
       col = (tile - 1)%self.nXtiles + 1
 
       return int(col)
 
     def _grid_coords(self, tileID):
-      
+
       i = self._tile_col(tileID)
       j = self._tile_row(tileID)
 
       return i, j
-    
+
     def _tile_id(self, grid_i, grid_j):
 
         t = grid_i + (grid_j-1)*self.nXtiles
         return t
-    
+
     def _neighbour_tiles(self, tile):
 
         i, j = self._grid_coords(tile)
@@ -488,7 +488,7 @@ class LaharFlowData(object):
             neighbours.append(self._tile_id(i, j+k))
             neighbours.append(self._tile_id(i+k, j+k))
             neighbours.append(self._tile_id(i+k, j-k))
-        
+
         return neighbours
 
     def _connected_tiles(self, tiles):
@@ -506,12 +506,12 @@ class LaharFlowData(object):
                     group.append(t)
                     in_group = True
                     break
-            
+
             if not in_group:
                 groups.append([t])
-    
+
         return groups
-    
+
     def _tile_row_groups(self, tiles):
 
         rows = [self._tile_row(t) for t in tiles]
@@ -541,19 +541,19 @@ class LaharFlowData(object):
         return (lat_res, lon_res)
 
     def get_XY(self):
-        
+
         x = ((np.arange(0,self.xSize,self.dX)-self.xSize/2)+self.dX/2)
         y = ((np.arange(0,self.ySize,self.dY)-self.ySize/2)+self.dY/2)
-        
+
         return x, y
-    
+
     def get_files(self):
         if self.zipped:
             files = self._zipref.namelist()
             self.files = [os.path.split(f)[1] for f in files]
         else:
             self.files = os.listdir(self.dir)
-    
+
     def get_tar_files(self):
         self.tar_files = [f for f in self.files if f.endswith('.tar.gz')]
         self.tar_files.sort()
@@ -561,7 +561,7 @@ class LaharFlowData(object):
     def get_nc_files(self):
         self.nc_files = [f for f in self.files if f.endswith('.nc')]
         self.nc_files.sort()
-    
+
     def get_gz_files(self):
         self.gz_files = [f for f in self.files if f.endswith('.gz')]
         self.gz_files.sort()
@@ -569,12 +569,12 @@ class LaharFlowData(object):
     def get_txt_files(self):
         self.txt_files = [f for f in self.files if f.endswith('.txt')]
         self.txt_files.sort()
-    
+
     def _snapshot_txt_files(self):
         txt_files = [f for f in self.txt_files if f.strip('.txt').isnumeric()]
         txt_files.sort()
         return txt_files
-    
+
     def _snapshot_nc_files(self):
         nc_files = [f for f in self.nc_files if f.strip('.nc').isnumeric()]
         nc_files.sort()
@@ -599,10 +599,10 @@ class LaharFlowData(object):
                 self.tiffFiles[str(f)] = this_file
                 k+=1
         return
-    
+
     def _update_tiff_files(self,file,epsg=None):
         assert(file.endswith('tif')), 'In updateTiff, file must have a .tif extension; received {}'.format(file)
-        
+
         n = len(self.tiffFiles)
         if epsg is None:
             with rio.open(os.path.join(self.dir,file)) as src:
@@ -628,7 +628,7 @@ class LaharFlowData(object):
         else:
             raise RuntimeError("Result must be either the name of file in directory {dirc}, or an integer".format(dirc=self.dir))
         return fileIn
-    
+
     def _file_type(self, filename):
         _ = self._valid_input_file(filename)
         if isinstance(filename, str):
@@ -644,7 +644,7 @@ class LaharFlowData(object):
                 filetype = 'snapshot'
         elif isinstance(filename, int):
             filetype = 'snapshot'
-        
+
         return filetype
 
     def _valid_variable(self, variable):
@@ -669,7 +669,7 @@ class LaharFlowData(object):
         elif filename in self.gz_files:
             LaharFlowFile = os.path.join(self.dir, filename)
             ExtractPath = self.dir
-        
+
         fname = os.path.split(LaharFlowFile)[1]
 
         if (fname in self.tar_files) and (fname not in self.txt_files):
@@ -688,7 +688,7 @@ class LaharFlowData(object):
     def _get_data_column_names(self, filename):
         filename = self._valid_input_file(filename)
         LaharFlowFile = self._extract_file(filename)
-        
+
         cols = csv_active_cols(LaharFlowFile)
         return cols
 
@@ -699,7 +699,7 @@ class LaharFlowData(object):
             return data
         except:
             raise RuntimeWarning('Unable to get data from {}'.format(LaharFlowFile))
-    
+
     def _get_data_nc(self, LaharFlowFile):
 
         data = nc2np(LaharFlowFile)
@@ -713,7 +713,7 @@ class LaharFlowData(object):
         filename = self._valid_input_file(filename)
 
         LaharFlowFile = self._extract_file(filename)
-        
+
         fileext = os.path.splitext(LaharFlowFile)[1]
 
         if fileext=='.txt':
@@ -748,9 +748,9 @@ class LaharFlowData(object):
             return False
         if latlon[1]>max_lon:
             return False
-        
+
         return True
-    
+
     def xy_in_data_extent(self, data, xy):
         fields = data.dtype.names
         if 'x_distance' not in fields:
@@ -771,28 +771,28 @@ class LaharFlowData(object):
             return False
         if xy[1]>max_y:
             return False
-        
+
         return True
-        
+
     def raster(self, filename, var=None, full_domain=False, nodata=np.nan, masked=True, crs=None, res=None):
-        
+
         filetype = self._file_type(filename)
         filename = self._valid_input_file(filename)
-        
+
         # LaharFlowFile = self._extract_file(filename)
         # print (LaharFlowFile)
-        
+
         # cols = csv_active_cols(LaharFlowFile)
         # data = np.genfromtxt(LaharFlowFile, delimiter=',', names=True, usecols=cols)
         data = self._get_data(filename)
-        
+
         extra_cols = ['tile', 'x_distance', 'y_distance', 'latitude', 'longitude']
         if var is None:
-            data_cols = [x for x in data.dtype.names 
+            data_cols = [x for x in data.dtype.names
                             if x not in extra_cols]
         else:
             data_cols = [x for x in var]
-        
+
         if res is None:
             res_lat, res_lon = self._get_latlon_res()
         else:
@@ -824,7 +824,7 @@ class LaharFlowData(object):
         uv[:,0] = grid_lat.flatten()
         uv[:,1] = grid_lon.flatten()
         vtx, wts = interp_weights(xy, uv)
-        
+
         for d, col in enumerate(data_cols):
             vals = interpolate(data[col], vtx, wts)
             grid_data = vals.reshape(grid_lat.shape[0], grid_lat.shape[1])
@@ -878,7 +878,7 @@ class LaharFlowData(object):
         #     uv[:,1] = grid_lon.flatten()
 
         #     vtx, wts = interp_weights(xy, uv)
-            
+
         #     for d, col in enumerate(data_cols):
         #         vals = interpolate(dat[col], vtx, wts)
         #         grid_data = vals.reshape(grid_lat.shape[0], grid_lat.shape[1])
@@ -901,13 +901,13 @@ class LaharFlowData(object):
         # for i, g in enumerate(tile_groups):
 
         #     row_groups = self._tile_row_groups(g)
-            
+
         #     for j, r in enumerate(row_groups):
 
         #         for k, t in enumerate(r):
         #             ds_tmp = xa.Dataset()
         #             ii = np.where(tiles==t)
-            
+
         #             dat = data[ii]
         #             ds_tmp.coords["y"] = np.unique(dat['y_distance'])# + self.utm[1]
         #             ds_tmp.coords["x"] = np.unique(dat['x_distance'])# + self.utm[0]
@@ -922,8 +922,8 @@ class LaharFlowData(object):
         #                 ds_tmp[col].attrs["symbol"] = fmt['symbol']
         #             ds_tmp.coords["Northing"] = (("y"), ds_tmp.y.data + self.utm[1])
         #             ds_tmp.coords["Easting"] = (("x"), ds_tmp.x.data + self.utm[0])
-                    
-            
+
+
         #             if k==0:
         #                 row = ds_tmp
         #             else:
@@ -931,12 +931,12 @@ class LaharFlowData(object):
 
         #         if j==0:
         #             raster[i] = row
-        #         else:     
+        #         else:
         #             raster[i] = xa.combine_nested([[raster[i], row]], concat_dim=['x','y'])
-            
+
         #     raster[i].x.attrs["units"] = "metres"
         #     raster[i].y.attrs["units"] = "metres"
-        
+
         #     raster[i] = raster[i].rio.write_crs(self.utmCode)
 
 
@@ -949,7 +949,7 @@ class LaharFlowData(object):
         #     else:
         #         dA[d].where(dA[d]==nodata, drop=True)
         #     ds[col] = dA[d]
-            
+
         #     # ds[col] = (("y","x"), array[:,:,d])
         #     ds[col].rio.write_nodata(nodata, inplace=True)
         #     fmt = _get_LF_output_fmt(col, filetype=filetype)
@@ -957,7 +957,7 @@ class LaharFlowData(object):
         #     ds[col].attrs["long_name"] = fmt['long_name']
         #     ds[col].attrs["units"] = fmt['units']
         #     ds[col].attrs["symbol"] = fmt['symbol']
-        
+
         # if filetype=='snapshot' and 'concentration' not in data_cols:
         #     ds['concentration'] = ds['mass_of_solids']
         #     ds['concentration'] = np.divide(ds['mass_of_solids'], ds['mass_per_unit_area'], where=ds['mass_per_unit_area'].where(ds['mass_per_unit_area'].data>1e-8))
@@ -971,7 +971,7 @@ class LaharFlowData(object):
 
     def _raster_flatten(self, raster, var):
         vals = raster[var].values.flatten()
-        rflat = vals[~np.isnan(vals)]    
+        rflat = vals[~np.isnan(vals)]
         return rflat
 
     def _get_data_column(self, filename, data_col):
@@ -986,7 +986,7 @@ class LaharFlowData(object):
             return x, y, d
         except:
             return None, None, None
-    
+
     def _data_to_array(self, x, y, data,
                        nodata=-1.0,
                        masked=True,
@@ -1003,7 +1003,7 @@ class LaharFlowData(object):
             x0 = ux
             y0 = uy
             array = nodata*np.ones((self.Nuy,self.Nux))
-        
+
         for k in range(0,len(x)):
             xk = x[k]
             yk = y[k]
@@ -1011,7 +1011,7 @@ class LaharFlowData(object):
             jj = np.where(xk==x0)
             if (vmin is None) or (data[k]>vmin):
                 array[ii,jj] = data[k]
-        
+
         if masked:
             array = np.ma.masked_where(array==nodata,array)
         return array
@@ -1022,32 +1022,32 @@ class LaharFlowData(object):
         data = self.raster(last_outfile, var=['elevation_change'])
 
         bt = data['elevation_change'].values
-        
+
         MaxErosion = max(-np.nanmin(bt),0.0)
         MaxDeposit = max(np.nanmax(bt),0.0)
 
         self.MaxErosion = MaxErosion
         self.MaxDeposit = MaxDeposit
         return
-    
+
     def max_bed_evolution(self, data=None, vmin=None, vmax=None):
         last_outfile = self.get_snapshot_files()[-1]
-        
+
         if data is None:
             data = self.raster(last_outfile)
         if 'elevation_change' not in list(data.keys()):
             data = self.raster(last_outfile)
-            
+
         bt = data['elevation_change']
-        
+
         if vmin is not None:
             bt = bt.where(bt.data>vmin)
-        
+
         if vmax is not None:
             bt = bt.where(bt.data<vmax)
-        
+
         return bt
-    
+
     def _get_nc_max(self):
         LaharFlowFile = self._extract_file('Maximums.nc')
         try:
@@ -1059,7 +1059,7 @@ class LaharFlowData(object):
             self.MaxDepth = None
             self.MaxSpeed = None
             self.MaxConc = None
-        
+
         last_outfile = self._snapshot_nc_files()[-1]
         LaharFlowFile = self._extract_file(last_outfile)
         try:
@@ -1072,16 +1072,16 @@ class LaharFlowData(object):
         return
 
     def _get_max_erosion(self):
-        
+
         last_outfile = self.get_snapshot_files()[-1]
         _, _, bt = self._get_data_column(last_outfile, 14)
-        
+
         self.MaxErosion = max(-np.amin(bt),0.0)
 
         return
 
     def _get_max_conc(self):
-        
+
         if 'Maximums.nc' in self.nc_files:
             LaharFlowFile = self._extract_file('Maximums.nc')
             try:
@@ -1096,14 +1096,14 @@ class LaharFlowData(object):
         return
 
     def _get_max_depth(self):
-        
+
         if 'Maximums.nc' in self.nc_files:
             LaharFlowFile = self._extract_file('Maximums.nc')
             try:
                 m = nc_max(LaharFlowFile, 'maximum_depth')
                 self.MaxDepth = m['maximum_depth']
             except:
-                self.MaxDepth = None            
+                self.MaxDepth = None
             return
         elif 'MaxHeights.txt' in self.txt_files:
             _, _, h = self._get_data_column('MaxHeights.txt', 5)
@@ -1113,7 +1113,7 @@ class LaharFlowData(object):
             print ('make this work')
             #raise RuntimeWarning('No data to determine maximum depth')
         return
-    
+
     def max_depth(self, data=None, vmin=None):
 
         if data is None:
@@ -1121,10 +1121,10 @@ class LaharFlowData(object):
                 data = self.raster('Maximums.nc')
             elif 'MaxHeights.txt' in self.txt_files:
                 data = self.raster('MaxHeights.txt')
-            
+
         if 'maximum_depth' not in list(data.keys()):
             raise RuntimeError('maximum_depth not in data')
-        
+
         maxh = data[['maximum_depth']]
 
         if vmin is not None:
@@ -1133,14 +1133,14 @@ class LaharFlowData(object):
         return maxh
 
     def _get_max_speed(self):
-        
+
         if 'Maximums.nc' in self.nc_files:
             LaharFlowFile = self._extract_file('Maximums.nc')
             try:
                 m = nc_max(LaharFlowFile, 'maximum_speed')
                 self.MaxSpeed = m['maximum_speed']
             except:
-                self.MaxSpeed = None            
+                self.MaxSpeed = None
             return
         elif 'MaxSpeeds.txt' in self.txt_files:
             _, _, spd = self._get_data_column('MaxSpeeds.txt', 5)
@@ -1149,7 +1149,7 @@ class LaharFlowData(object):
         else:
             print ('make this work')
             #raise RuntimeWarning('No data to determine maximum speed')
-        
+
     def max_speed(self, data=None, vmin=None):
 
         if data is None:
@@ -1157,7 +1157,7 @@ class LaharFlowData(object):
                 data = self.raster('Maximums.nc')
             elif 'MaxSpeeds.txt' in self.txt_files:
                 data = self.raster('MaxSpeeds.txt')
-            
+
         if 'maximum_speed' not in list(data.keys()):
             raise RuntimeError('maximum_speed not in data')
 
@@ -1167,7 +1167,7 @@ class LaharFlowData(object):
             maxspd = maxspd.where(maxspd>vmin, drop=True)
 
         return maxspd
-    
+
     def inundation_time(self, data=None, vmin=None):
 
         if data is None:
@@ -1179,21 +1179,21 @@ class LaharFlowData(object):
 
         if vmin is not None:
             itime =itime.where(itime>vmin, drop=True)
-        
+
         return itime
 
     def _get_max_deposit(self):
 
         last_outfile = self.get_snapshot_files()[-1]
         _, _, bt = self._get_data_column(last_outfile, 14)
-        
+
         self.MaxDeposit = max(np.amax(bt),0.0)
 
     def _get_max_erosion(self):
-        
+
         last_outfile = self.get_snapshot_files()[-1]
         _, _, bt = self._get_data_column(last_outfile, 14)
-        
+
         self.MaxErosion = max(-np.amin(bt),0.0)
 
     def snapshot_data(self,fnum):
@@ -1206,23 +1206,23 @@ class LaharFlowData(object):
         cols = csv_active_cols(LaharFlowFile)
         data = np.genfromtxt(LaharFlowFile,delimiter=',',names=True,usecols=cols)
         return data
-    
+
     def snapshot_variable(self, fnum, var, vmin=None, full_domain=False):
-        
+
         dataset = self.raster(fnum, full_domain=full_domain)
 
         valid_vars = _LFoutput_shortnames
 
         if var not in valid_vars:
             raise ValueError("variable name must be one of {names}, received '{var}'".format(names=valid_vars, var=var))
-        
+
         dat = dataset[var]
 
         if vmin is not None:
             dat = dat.where(dat.data>vmin)
 
         return dat
-    
+
     def clip_raster(self, raster, clip_gdf):
         # Clip raster data to geodataframe clip_gdf
 
@@ -1239,7 +1239,7 @@ class LaharFlowData(object):
             return None
 
         return data_clipped
-        
+
     def _raster_contour(self, raster, var, cntrs):
 
         data = raster[var].values
@@ -1248,14 +1248,14 @@ class LaharFlowData(object):
         lat = raster.latitude.data
 
         dlon, dlat = raster.rio.resolution()
-        
+
         fx = interp1d(np.arange(0,len(lon)),lon)
         fy = interp1d(np.arange(0,len(lat)),lat)
 
         for kk, this_cntr in enumerate(cntrs):
-            
+
             new_set = True
-            
+
             cdata = np.zeros_like(data)
             cdata[data>=this_cntr] = 1
             C = find_contours(cdata, 0.5)
@@ -1266,39 +1266,39 @@ class LaharFlowData(object):
                 if len(p)>2:
                     p[:,0] = fy(p[:, 0])
                     p[:,1] = fx(p[:, 1])
-                    
+
                     p[:, [0, 1]] = p[:, [1, 0]]
-                
+
                     thisPoly = Polygon(p).buffer(0)
-                
+
                     if not thisPoly.is_empty:
                         if new_set:
                             new_set = False
                             geom = thisPoly
-                            
+
                         else:
                             geom1 = thisPoly
-                            
+
                             geom = geom.symmetric_difference(geom1)
-                            
+
             g_tmp = gpd.GeoDataFrame(columns=['contour', 'name', 'geometry'],
                                  crs=wgs84)
             g_tmp.loc[0, 'contour'] = this_cntr
             g_tmp.loc[[0], 'geometry'] = gpd.GeoSeries(geom)
             g_tmp.loc[0, 'name'] = var
-                
+
             if kk==0:
                 g = gpd.GeoDataFrame(g_tmp).set_geometry('geometry')
             else:
                 g = gpd.GeoDataFrame(pd.concat([g, g_tmp], ignore_index=True))
-            
+
         g['contour'] = g['contour'].astype('float64')
         g = g.set_crs(crs)
-        
+
         return g
 
     def max_depth_contours(self, data=None, var='maximum_depth', cntrs=0.1, vmin=0.1):
-        
+
         maxh = self.max_depth(data=data, vmin=vmin)
 
         if maxh is not None:
@@ -1311,16 +1311,16 @@ class LaharFlowData(object):
                     cntrs = cntrs[:-1]
                 if type(cntrs) is not list:
                     cntrs = [cntrs]
-            
+
             cntrs.sort()
-        
+
             g = self._raster_contour(maxh, var, cntrs)
             return g
         else:
             return None
-    
+
     def max_speed_contours(self, data=None, name='MaxSpeeds',cntrs=1, vmin=None):
-        
+
         maxspd = self.max_speed(data=data, vmin=vmin)
 
         if maxspd is not None:
@@ -1334,16 +1334,16 @@ class LaharFlowData(object):
                     cntrs = cntrs[:-1]
                 if type(cntrs) is not list:
                     cntrs = [cntrs]
-            
+
             cntrs.sort()
-        
+
             g = self._raster_contour(maxspd, name, cntrs)
             return g
         else:
             return None
 
     def inundation_time_contours(self, data=None, name='InundationTime',cntrs=0,vmin=0):
-        
+
         itime = self.inundation_time(data=data, vmin=vmin)
 
         if itime is not None:
@@ -1356,20 +1356,20 @@ class LaharFlowData(object):
                     cntrs = cntrs[:-1]
                 if type(cntrs) is not list:
                     cntrs = [cntrs]
-            
+
             cntrs.sort()
-            
+
             g = self._raster_contour(time, name, cntrs)
-            
+
             return g
         else:
             return None
-    
+
     def POI_value(self,  lon, lat, data=None, filename=None, var=None, full_domain=False, nodata=np.nan, fill_value=0, interp_method='linear'):
-        
+
         if data is None and filename is None:
             raise RuntimeError('cannot have both data=None and filename=None')
-        
+
         if data is not None and filename is not None:
             raise RuntimeError('cannot give both data and filename')
 
@@ -1386,22 +1386,22 @@ class LaharFlowData(object):
 
         if fill_value is not None:
             data = data.fillna(fill_value)
-        
+
         value = data.interp(longitude=lon, latitude=lat, method=interp_method)
 
         val = dict()
         vars = var if var is not None else list(data.keys())
         for v in vars:
             val[v] = value[v].values
-        
+
         return val
-    
+
     def POI_buffer(self,  lon, lat, buffer, data=None, filename=None, var=None,
                    nodata=np.nan):
-        
+
         if data is None and filename is None:
             raise RuntimeError('cannot have both data=None and filename=None')
-        
+
         if data is not None and filename is not None:
             raise RuntimeError('cannot give both data and filename')
 
@@ -1416,24 +1416,24 @@ class LaharFlowData(object):
             indx = np.sqrt((data['x_distance']-POI_xy[0])**2+(data['y_distance']-POI_xy[1])**2)<buffer
 
             data_clipped = data[var][indx]
-        
+
             return data_clipped
         else:
             return nodata
-    
-    def transect_value(self, x, y, filename=None, data=None, var=None, full_domain=False, nodata=np.nan, fill_value=0, interp_method='linear'):
-        
+
+    def transect_value(self, lon, lat, filename=None, data=None, var=None, full_domain=False, nodata=np.nan, fill_value=0, interp_method='linear'):
+
         if data is None and filename is None:
             raise RuntimeError('cannot have both data=None and filename=None')
-        
+
         if data is not None and filename is not None:
             raise RuntimeError('cannot give both data and filename')
 
         if not isinstance(var, list):
             var = [var]
 
-        xA = xa.DataArray(x, dims="z")
-        yA = xa.DataArray(y, dims="z")
+        lonA = xa.DataArray(lon, dims="z")
+        latA = xa.DataArray(lat, dims="z")
 
         if interp_method not in ['nearest', 'linear']:
             raise RuntimeError("currently only works with nearest or linear interpolation")
@@ -1446,8 +1446,8 @@ class LaharFlowData(object):
 
         if fill_value is not None:
             data = data.fillna(fill_value)
-        
-        value = data.interp(x=xA, y=yA, method=interp_method)
+
+        value = data.interp(longitude=lonA, latitude=latA, method=interp_method)
 
         val = dict()
         vars = var if var is not None else list(data.keys())
@@ -1474,9 +1474,9 @@ class LaharFlowData(object):
 
         print('Writing file to {}'.format(fileOut))
         raster.rio.to_raster(fileOut)
-        
+
         return
-    
+
     def plot(self, result, variable,
                  crs=webmerc,
                  ax=None,
@@ -1507,24 +1507,24 @@ class LaharFlowData(object):
         if vmax is None:
             maxval = np.nanmax(data)
             vmax = _nice_round(maxval)
-        
+
         if vmin is None:
             vmin = np.nanmin(data)
-        
+
         if vcut is not None:
             data = np.ma.masked_inside(data, vcut[0], vcut[1])
-        
+
         if vmin<0 and vmax>0:
             cnorm = colors.TwoSlopeNorm(vmin=vmin, vmax=vmax, vcenter=0)
         else:
             cnorm = colors.Normalize(vmin=vmin, vmax=vmax)
-        
+
         if clip_low:
             data = np.ma.masked_less(data, vmin)
 
         if ax is None:
             fig, ax = plt.subplots()
-        
+
         im = ax.imshow(data,
                        interpolation=interpolation,
                        cmap=cmap,
@@ -1535,12 +1535,12 @@ class LaharFlowData(object):
         if cax is None:
             divider = make_axes_locatable(ax)
             cax = divider.append_axes("right", size="5%", pad=0.05)
-        
+
         cbar = plt.colorbar(im, cax=cax, orientation=orientation)
-        cbar.ax.set_ylabel(fmt['short_name'].replace('_',' ') 
+        cbar.ax.set_ylabel(fmt['short_name'].replace('_',' ')
                             + ' ({unit})'.format(unit=fmt['units']))
-        
-        ax.get_xaxis().set_visible(False) 
+
+        ax.get_xaxis().set_visible(False)
         ax.get_yaxis().set_visible(False)
 
         return ax, im, cbar
